import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { EquipoPrograma } from '../../../equipo-programa/entity/equipo-programa.entity';
import { EquipoTipoEntrada } from '../../../equipo-tipo-entrada/entity/equipo-tipo-entrada.entity';
import { Programa } from '../../../institucion-programa/entity/programa.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';
import { TipoEntrada } from '../../../institucion-tipo-entrada/entity/tipo-entrada.entity';
import { Status } from '../../../status/entity/status.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .from(Equipo, 'e')
      .select('e.id_equipo', 'id_equipo')
      .addSelect('e.prestado', 'prestado')
      .addSelect('c.activo', 'activo')
      .addSelect('s.id_status', 'id_status')
      .addSelect('m.id_modulo', 'id_modulo')
      .addSelect('i.id_institucion', 'id_institucion')
      // .addSelect('p.id_programa')
      // .addSelect('p.id_programa')
      // .addSelect('te.id_tipo_entrada')
      // .addSelect('tc.id_tipo_carrito')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(EquipoPrograma, 'ps', 'ps.id_equipo = e.id_equipo')
      .innerJoin(EquipoTipoEntrada, 'tes', 'tes.id_equipo = e.id_equipo')
      .innerJoin(Status, 's', 's.id_status = e.id_status')
      // .innerJoin(TipoEntrada, 'te', 'te.id_tipo_entrada = c.id_tipo_entrada')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      // .innerJoin(Programa, 'p', 'p.id_programa = e.id_programa')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion')
      .where(
        'e.prestado = 1 && s.id_status = 1 && c.activo = 1 && m.activo = 1 && i.activo = 1',
      ),
})
export class EquipoPrestamoView {
  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  prestado: boolean;

  @ViewColumn()
  activo: boolean;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_institucion: number;
}
