import {
  Body,
  Controller,
  ForbiddenException,
  Put,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { InstitucionUsuarioService } from './institucion-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { UpdateInstitucionUsuarioInputDto } from './dto/input/update.dto';

@Controller('institucion-usuario')
@ApiTags('institucion-usuario')
export class InstitucionUsuarioController {
  constructor(private institucionUsuarioService: InstitucionUsuarioService) {}

  @Put()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Enpoint que actualiza la información de un usuario.',
  })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Todas las variables a excepción de id_ son opcionales.',
    examples: {
      ejemplo: {
        value: {
          correo: '',
          id_usuario: 1,
          telefono: '',
        },
      },
    },
  })
  update(@Request() req, @Body() body: UpdateInstitucionUsuarioInputDto) {
    const admin: Operador = req.user.operador;

    if (
      !admin ||
      (admin.tipoUsuario.id_tipo_usuario != 3 &&
        admin.tipoUsuario.id_tipo_usuario != 4)
    )
      throw new ForbiddenException(
        'No tienes los permisos necesarios para realizar esta acción.',
      );
    return this.institucionUsuarioService.update(body);
  }
}
